.. kisee documentation master file, created by
   sphinx-quickstart on Fri Jul 12 10:40:09 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kisee's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installing
   features
   settings
   api
   contributing
   faq


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
